/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-accessibility-helpers--page#description-id)
 *
 * Takes the ID of an element and generates a new ID. This should be set as the ID of an element that describes the first element. The generated ID should also be passed to the `aria-describedby` attribute on the first element.
 *
 * @param {string} id - ID of an element
 * @returns {string} ID of an element that describes the first element
 *
 * @example
 *		<form>
 *			<input id={id} type="text" aria-describedby={descriptionId(id)} />
 *			<p class="error" id={descriptionId(id)} />
 *		</form>
 */
declare const descriptionId: (id: string) => string;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-accessibility-helpers--page#focus-halo)
 *
 * Provides a clear focus state to support keyboard navigation.
 */
declare const focusHalo: string;
declare const generateSourceId: () => string;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-accessibility-helpers--page#visually-hidden-elements)
 *
 * For elements that need to be hidden from sighted users and displayed to screen reader users.
 */
declare const visuallyHidden = "\n\tposition: absolute;\n\topacity: 0;\n\theight: 0;\n\twidth: 0;\n\ttop: 0;\n\tleft: 0;\n";
declare const transitions: {
    short: string;
    medium: string;
    long: string;
};
type Breakpoint = "mobile" | "mobileMedium" | "mobileLandscape" | "phablet" | "tablet" | "desktop" | "leftCol" | "wide";
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-media-queries--page#breakpoints) •
 * [Design System](https://theguardian.design/2a1e5182b/p/41be19-grids)
 */
declare const breakpoints: {
    readonly mobile: 320;
    readonly mobileMedium: 375;
    readonly mobileLandscape: 480;
    readonly phablet: 660;
    readonly tablet: 740;
    readonly desktop: 980;
    readonly leftCol: 1140;
    readonly wide: 1300;
};
type BreakpointMap = {
    [key in Breakpoint]: string;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-media-queries--page#from)
 *
 * @example
 *	const styles = css`
 *		${from.mobileLandscape} {
 *			padding: 0 20px;
 *		}
 * `;
 */
declare const from: BreakpointMap;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-media-queries--page#until)
 *
 * @example
 *	const styles = css`
 *		${until.wide} {
 *			padding: 0 40px;
 *		}
 * `;
 */
declare const until: BreakpointMap;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-media-queries--page#betweenand)
 *
 * @example
 *	const styles = css`
 *		${between.phablet.and.desktop} {
 *			padding: 0 32px;
 *		}
 * `;
 */
declare const between: {
    mobile: {
        and: {
            mobileMedium: string;
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileMedium: {
        and: {
            mobileLandscape: string;
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    mobileLandscape: {
        and: {
            phablet: string;
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    phablet: {
        and: {
            tablet: string;
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    tablet: {
        and: {
            desktop: string;
            leftCol: string;
            wide: string;
        };
    };
    desktop: {
        and: {
            leftCol: string;
            wide: string;
        };
    };
    leftCol: {
        and: {
            wide: string;
        };
    };
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/66411c)
 *
 * Our core brand colour – `brand[400]` – and extended brand colours
 */
declare const brand: {
    100: "#001536";
    300: "#041F4A";
    400: "#052962";
    500: "#007ABC";
    600: "#506991";
    800: "#C1D8FC";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/32d461)
 *
 * Our alternative brand colours
 */
declare const brandAlt: {
    200: "#F3C100";
    300: "#FFD900";
    400: "#FFE500";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/70dd5c)
 *
 * Neutral colours
 */
declare const neutral: {
    0: "#000000";
    7: "#121212";
    10: "#1A1A1A";
    20: "#333333";
    46: "#707070";
    60: "#999999";
    86: "#DCDCDC";
    93: "#EDEDED";
    97: "#F6F6F6";
    100: "#FFFFFF";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/98b901)
 *
 * Error colours
 */
declare const error: {
    400: "#C70000";
    500: "#FF9081";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/82798f)
 *
 * Success colours
 */
declare const success: {
    400: "#22874D";
    500: "#58D08B";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/97d77e)
 *
 * News colours
 */
declare const news: {
    100: "#660505";
    200: "#8B0000";
    300: "#AB0613";
    400: "#C70000";
    500: "#FF5943";
    550: "#FF9081";
    600: "#FFBAC8";
    800: "#FFF4F2";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/0539ef)
 *
 * Opinion colours
 */
declare const opinion: {
    100: "#672005";
    200: "#8D2700";
    300: "#C74600";
    400: "#E05E00";
    500: "#FF7F0F";
    550: "#FF9941";
    600: "#F9B376";
    800: "#FEF9F5";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/957a45)
 *
 * Sport colours
 */
declare const sport: {
    100: "#003C60";
    200: "#004E7C";
    300: "#005689";
    400: "#0077B6";
    500: "#00B2FF";
    600: "#90DCFF";
    800: "#F1F8FC";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/068eb2)
 *
 * Culture colours
 */
declare const culture: {
    50: "#2B2625";
    100: "#3E3323";
    200: "#574835";
    300: "#6B5840";
    350: "#866D50";
    400: "#A1845C";
    500: "#EACCA0";
    600: "#E7D4B9";
    700: "#EFE8DD";
    800: "#FBF6EF";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/2236b4)
 *
 * Lifestyle colours
 */
declare const lifestyle: {
    100: "#510043";
    200: "#650054";
    300: "#7D0068";
    400: "#BB3B80";
    500: "#FFABDB";
    600: "#FEC8D3";
    800: "#FEEEF7";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/59b08c)
 *
 * Labs colours
 */
declare const labs: {
    200: "#4B8878";
    300: "#65A897";
    400: "#69D1CA";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/31c634)
 *
 * Special report colours
 */
declare const specialReport: {
    100: "#222527";
    200: "#303538";
    300: "#3F464A";
    400: "#595C5F";
    450: "#9DA0A2";
    500: "#ABC2C9";
    700: "#E4E5E8";
    800: "#EFF1F2";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/492a30-light-palette/t/188e86)
 *
 * Focus state colour
 */
declare const focus: {
    400: "#0093E0";
};
// Hover colours are snowflakes as they are manipulations of colours from the
// main palette.
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/9280ee)
 *
 * Default theme background colours
 */
declare const background: {
    readonly primary: "#FFFFFF";
    readonly secondary: "#F6F6F6";
    readonly inverse: "#1A1A1A";
    readonly ctaPrimary: "#052962";
    readonly ctaPrimaryHover: "#234B8A";
    readonly ctaSecondary: "#C1D8FC";
    readonly ctaSecondaryHover: "#ACC9F7";
    readonly ctaTertiaryHover: "#E5E5E5";
    readonly input: "#FFFFFF";
    readonly inputChecked: "#007ABC";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/63cc10)
 *
 * Brand theme background colours
 */
declare const brandBackground: {
    readonly primary: "#052962";
    readonly inputChecked: "#FFFFFF";
    readonly ctaPrimary: "#FFFFFF";
    readonly ctaPrimaryHover: "#E0E0E0";
    readonly ctaSecondary: "#506991";
    readonly ctaSecondaryHover: "#234B8A";
    readonly ctaTertiaryHover: "#041F4A";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/743232)
 *
 * Alternative brand theme background colours
 */
declare const brandAltBackground: {
    readonly primary: "#FFE500";
    readonly ctaPrimary: "#121212";
    readonly ctaPrimaryHover: "#454545";
    readonly ctaSecondary: "#F3C100";
    readonly ctaSecondaryHover: "#F2AE00";
    readonly ctaTertiaryHover: "#FFD213";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/69c92f)
 *
 * Default theme border colours
 */
declare const border: {
    primary: "#999999";
    secondary: "#DCDCDC";
    success: "#22874D";
    error: "#C70000";
    ctaTertiary: "#052962";
    input: "#999999";
    inputChecked: "#007ABC";
    inputHover: "#007ABC";
    inputActive: "#007ABC";
    focusHalo: "#0093E0";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/04883b)
 *
 * Brand theme border colours
 */
declare const brandBorder: {
    primary: "#506991";
    secondary: "#506991";
    success: "#58D08B";
    error: "#FF9081";
    ctaTertiary: "#FFFFFF";
    input: "#C1D8FC";
    inputChecked: "#FFFFFF";
    inputHover: "#FFFFFF";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/b/21c6cc)
 *
 * Alternative brand theme border colours
 */
declare const brandAltBorder: {
    ctaTertiary: "#121212";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/593cc9)
 *
 * Default theme line colours
 */
declare const line: {
    primary: "#DCDCDC";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/66455d)
 *
 * Brand theme line colours
 */
declare const brandLine: {
    primary: "#506991";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/89955e)
 *
 * Alternative brand theme line colours
 */
declare const brandAltLine: {
    primary: "#121212";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/85d3b0)
 *
 * Default theme text colours
 */
declare const text: {
    primary: "#121212";
    supporting: "#707070";
    success: "#22874D";
    error: "#C70000";
    ctaPrimary: "#FFFFFF";
    ctaSecondary: "#052962";
    ctaTertiary: "#052962";
    anchorPrimary: "#007ABC";
    anchorSecondary: "#121212";
    userInput: "#121212";
    inputLabel: "#121212";
    inputError: "#121212";
    inputLabelSupporting: "#707070";
    inputChecked: "#052962";
    inputHover: "#052962";
    groupLabel: "#121212";
    groupLabelSupporting: "#707070";
    newsInverse: "#FF9081";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/244480)
 *
 * Brand theme text colours
 */
declare const brandText: {
    primary: "#FFFFFF";
    supporting: "#C1D8FC";
    success: "#58D08B";
    error: "#FF9081";
    ctaPrimary: "#052962";
    ctaSecondary: "#FFFFFF";
    ctaTertiary: "#FFFFFF";
    anchorPrimary: "#FFFFFF";
    anchorPrimaryHover: "#FFE500";
    userInput: "#FFFFFF";
    inputLabel: "#FFFFFF";
    inputLabelSupporting: "#C1D8FC";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-colour--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/1377a6-tokens/t/11d5fd)
 *
 * Alternative brand theme text colours
 */
declare const brandAltText: {
    primary: "#121212";
    supporting: "#999999";
    ctaPrimary: "#FFFFFF";
    ctaSecondary: "#121212";
    ctaTertiary: "#121212";
    anchorPrimary: "#121212";
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-size--page#global-size-values) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * May be used for call to action buttons and user input fields.
 */
declare const size: {
    readonly xsmall: 24;
    readonly small: 36;
    readonly medium: 44;
};
/*
We attempt to use these values for icons within Source components.
They are analogous with component heights defined by the size values
above. They are based on the size of icons used within the button
component.
*/
declare const iconSize: {
    readonly xsmall: 20;
    readonly small: 26;
    readonly medium: 30;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in px
 *
 ** `height.ctaMedium`: call to action buttons and links
 ** `height.ctaSmall`: secondary calls to action
 ** `height.ctaXsmall`: calls to action where there is very limited space
 ** `height.inputMedium`: text input fields, radio and checkbox labels
 ** `height.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `height.iconMedium`
 ** `height.iconSmall`
 ** `height.iconXsmall`
 */
declare const height: {
    ctaMedium: 44;
    ctaSmall: 36;
    ctaXsmall: 24;
    inputMedium: 44;
    inputXsmall: 24;
    iconMedium: 30;
    iconSmall: 26;
    iconXsmall: 20;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/24a3ec-size/t/329aef)
 *
 * Height tokens expressed in rem
 *
 ** `remHeight.ctaMedium`: call to action buttons and links
 ** `remHeight.ctaSmall`: secondary calls to action
 ** `remHeight.ctaXsmall`: calls to action where there is very limited space
 ** `remHeight.inputMedium`: text input fields, radio and checkbox labels
 ** `remHeight.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remHeight.iconMedium`
 ** `remHeight.iconSmall`
 ** `remHeight.iconXsmall`
 */
declare const remHeight: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputMedium: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in px
 *
 ** `width.ctaMedium`: medium height call to action buttons and links
 ** `width.ctaSmall`: small height call to action buttons and links
 ** `width.ctaXsmall`: xsmall height call to action buttons and links
 ** `width.inputMedium`: text input fields, radio and checkbox labels
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.inputMedium`
 ** `width.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `width.iconMedium`
 ** `width.iconSmall`
 ** `width.iconXsmall`
 */
declare const width: {
    ctaMedium: 44;
    ctaSmall: 36;
    ctaXsmall: 24;
    inputXsmall: 24;
    iconMedium: 30;
    iconSmall: 26;
    iconXsmall: 20;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-size--page#tokens) •
 * [Design System](https://theguardian.design/2a1e5182b/p/00ddcb-tokens/t/797660)
 *
 * Width tokens expressed in rem
 *
 ** `remWidth.ctaMedium`: medium height call to action buttons and links
 ** `remWidth.ctaSmall`: small height call to action buttons and links
 ** `remWidth.ctaXsmall`: xsmall height call to action buttons and links
 ** `remWidth.inputMedium`: text input fields, radio and checkbox labels
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.inputMedium`
 ** `remWidth.inputXsmall`: checkables such as checkboxes or radio buttons
 ** `remWidth.iconMedium`
 ** `remWidth.iconSmall`
 ** `remWidth.iconXsmall`
 */
declare const remWidth: {
    ctaMedium: number;
    ctaSmall: number;
    ctaXsmall: number;
    inputXsmall: number;
    iconMedium: number;
    iconSmall: number;
    iconXsmall: number;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-space--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/05f835-space)
 *
 * Can be applied to margin or padding properties, vertically or horizontally.
 *
 ** `space[1]` -> 4px
 ** `space[2]` -> 8px
 ** `space[3]` -> 12px
 ** `space[4]` -> 16px
 ** `space[5]` -> 20px
 ** `space[6]` -> 24px
 ** `space[9]` -> 36px
 ** `space[12]` -> 48px
 ** `space[24]` -> 96px
 */
declare const space: {
    readonly 1: 4;
    readonly 2: 8;
    readonly 3: 12;
    readonly 4: 16;
    readonly 5: 20;
    readonly 6: 24;
    readonly 9: 36;
    readonly 12: 48;
    readonly 24: 96;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-space--page) •
 * [Design System](https://theguardian.design/2a1e5182b/p/05f835-space)
 *
 * Can be applied to margin or padding properties, vertically or horizontally.
 *
 ** `remSpace[1]` -> 0.25rem
 ** `remSpace[2]` -> 0.5rem
 ** `remSpace[3]` -> 0.75rem
 ** `remSpace[4]` -> 1rem
 ** `remSpace[5]` -> 1.25rem
 ** `remSpace[6]` -> 1.5rem
 ** `remSpace[9]` -> 2.25rem
 ** `remSpace[12]` -> 3rem
 ** `remSpace[24]` -> 6rem
 */
declare const remSpace: {
    [K in keyof typeof space]: string;
};
type ScaleUnit = "rem" | "px";
type Category = "titlepiece" | "headline" | "body" | "textSans";
type LineHeight = "tight" | "regular" | "loose";
type FontWeight = "light" | "regular" | "medium" | "bold";
type FontStyle = "normal" | "italic";
type FontWeightDefinition = {
    hasItalic: boolean;
};
type Option<A> = A | null;
type TypographyStyles = {
    fontFamily: string;
    fontSize: string | number;
    lineHeight: string | number;
    fontWeight?: number;
    fontStyle?: string;
};
type TypographySizes = {
    [key in string]: number;
};
interface TitlepieceSizes extends TypographySizes {
    small: number;
    medium: number;
    large: number;
}
interface HeadlineSizes extends TypographySizes {
    xxxsmall: number;
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
}
interface BodySizes extends TypographySizes {
    small: number;
    medium: number;
}
interface TextSansSizes extends TypographySizes {
    xxsmall: number;
    xsmall: number;
    small: number;
    medium: number;
    large: number;
    xlarge: number;
    xxlarge: number;
    xxxlarge: number;
}
type Fs = (category: Category) => (level: string, { lineHeight, fontWeight, fontStyle, unit }: {
    lineHeight: LineHeight;
    fontWeight: FontWeight;
    fontStyle: Option<FontStyle>;
    unit: ScaleUnit;
}) => TypographyStyles;
type FontScaleFunction = (options?: FontScaleArgs) => TypographyStyles;
// returns styles as a template literal
type FontScaleFunctionStr = (options?: FontScaleArgs) => string;
interface FontScaleArgs {
    lineHeight?: LineHeight;
    fontWeight?: FontWeight;
    fontStyle?: FontStyle;
    unit?: ScaleUnit;
}
declare const titlepieceSizes: TitlepieceSizes;
declare const headlineSizes: HeadlineSizes;
declare const bodySizes: BodySizes;
declare const textSansSizes: TextSansSizes;
declare const remTitlepieceSizes: TitlepieceSizes;
declare const remHeadlineSizes: HeadlineSizes;
declare const remBodySizes: BodySizes;
declare const remTextSansSizes: TextSansSizes;
declare const fontMapping: {
    [cat in Category]: string;
};
declare const lineHeightMapping: {
    [lineHight in LineHeight]: number;
};
declare const fontWeightMapping: {
    [fontWeight in FontWeight]: number;
};
type TypographyApi<Sizes> = {
    [key in keyof Sizes]: FontScaleFunctionStr;
};
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#titlepiece) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/358767)
 *
 * ```
 * font-family: 'GT Guardian Titlepiece';
 * ```
 *
 * `titlepiece.small()` -> 42px
 *
 * `titlepiece.medium()` -> 50px
 *
 * `titlepiece.large()` -> 70px
 */
declare const titlepiece: TypographyApi<TitlepieceSizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#headline) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/7310bd)
 *
 * ```
 * font-family: 'GH Guardian Headline';
 * ```
 *
 * `headline.xxxsmall()` -> 17px
 *
 * `headline.xxsmall()` -> 20px
 *
 * `headline.xsmall()` -> 24px
 *
 * `headline.small()` -> 28px
 *
 * `headline.medium()` -> 34px
 *
 * `headline.large()` -> 42px
 *
 * `headline.xlarge()` -> 50px
 */
declare const headline: TypographyApi<HeadlineSizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#body) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/88cd8e)
 *
 * ```
 * font-family: 'GuardianTextEgyptian';
 * ```
 *
 * `body.small()` -> 15px
 *
 * `body.medium()` -> 17px
 */
declare const body: TypographyApi<BodySizes>;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-typography--page#text-sans) •
 * [Design System](https://theguardian.design/2a1e5182b/p/602314-typography/t/076605)
 *
 * ```
 * font-family: 'GuardianTextSans';
 * ```
 *
 * `textSans.xxsmall()` -> 12px
 *
 * `textSans.xsmall()` -> 14px
 *
 * `textSans.small()` -> 15px
 *
 * `textSans.medium()` -> 17px
 *
 * `textSans.large()` -> 20px
 *
 * `textSans.xlarge()` -> 24px
 *
 * `textSans.xxlarge()` -> 28px
 *
 * `textSans.xxxlarge()` -> 34px
 */
declare const textSans: TypographyApi<TextSansSizes>;
type TitlepieceFunctions = {
    [key in keyof TitlepieceSizes]: FontScaleFunction;
};
declare const titlepiece$0: TitlepieceFunctions;
type HeadlineFunctions = {
    [key in keyof HeadlineSizes]: FontScaleFunction;
};
declare const headline$0: HeadlineFunctions;
type BodyFunctions = {
    [key in keyof BodySizes]: FontScaleFunction;
};
declare const body$0: BodyFunctions;
type TextSansFunctions = {
    [key in keyof TextSansSizes]: FontScaleFunction;
};
declare const textSans$0: TextSansFunctions;
declare const appearance = "(appearance: none) or (-webkit-appearance: none) or (-moz-appearance: none)";
declare const FocusStyleManager: {
    alwaysShowFocus: () => void;
    isActive: () => boolean;
    onlyShowFocusOnTabs: () => void;
};
declare const rootPixelFontSize = 16;
declare const pxToRem: (px: number) => number;
/**
 * [Storybook](https://guardian.github.io/source/?path=/docs/packages-source-foundations-css-reset--page)
 *
 * `resets.resetCSS`: sensible default CSS rules to provide a base for a consistent environment across projects and browsers.
 */
declare const resets: {
    legend: string;
    fieldset: string;
    input: string;
    defaults: string;
    resetCSS: string;
};
declare const svgBackgroundImage: (svg: string) => string;
export { descriptionId, focusHalo, generateSourceId, visuallyHidden, transitions, Breakpoint, breakpoints, between, from, until, brand, brandAlt, neutral, error, success, news, opinion, sport, culture, lifestyle, labs, specialReport, focus, background, brandBackground, brandAltBackground, border, brandBorder, brandAltBorder, line, brandLine, brandAltLine, text, brandText, brandAltText, height, iconSize, remHeight, remWidth, size, width, space, remSpace, titlepiece, headline, body, textSans, titlepieceSizes, headlineSizes, bodySizes, textSansSizes, remTitlepieceSizes, remHeadlineSizes, remBodySizes, remTextSansSizes, fontMapping as fonts, fontWeightMapping as fontWeights, lineHeightMapping as lineHeights, body$0 as bodyObjectStyles, headline$0 as headlineObjectStyles, textSans$0 as textSansObjectStyles, titlepiece$0 as titlepieceObjectStyles, ScaleUnit, Category, LineHeight, FontWeight, FontStyle, FontWeightDefinition, Option, TypographyStyles, TypographySizes, TitlepieceSizes, HeadlineSizes, BodySizes, TextSansSizes, Fs, FontScaleFunction, FontScaleFunctionStr, FontScaleArgs, appearance, FocusStyleManager, pxToRem, rootPixelFontSize, resets, svgBackgroundImage };
//# sourceMappingURL=index.cjs.d.ts.map